/*
 * VirtuaWin-RUN v1.1
 * Simple helper utility for VirtuaWin v2.5 (read below).
 *
 * (C) 2001 Thomas Wolf (twoii@chello.at)
 *
 * Compiled using Borland's free BCC32 v5.5 and licensed
 * through the GNU general public license. See COPYING.TXT
 * for the complete license.
 *
 * Syntax: vwrun <n> [<app> [<params>]] [/stay]
 *
 * If run with <n> only switches to VirtuaWin desktop number <n>.
 * If run with <n> and with second parameter specifying the full
 * path to an application (may use system variables) switches to
 * desktop number <n>, executes given application, and switches
 * back to old desktop number. If you specify the "/stay" param
 * VWRUN won't switch back to the old desktop after the given
 * application was executed.
 *
 * Here's an Win2000/XP example that executes notepad on desktop
 * number two and that switches back to old desktop afterwards:
 *
 *   vwrun 2 %SystemRoot%\notepad.exe
 *
 * And another example that executes Photoshop5 on desktop 4 and
 * that loads up some image file and that does NOT switch back to
 * the old desktop number (you could also specify the whole cmd-
 * line as a single parameter):
 *
 *   vwrun 4 "C:\Program Files\Adobe\Photoshop 5.0\photoshp.exe"
 *    "C:\My Documents\Photoshop5\MyImage.psd" /stay
 */
#include <windows.h>
#include <dos.h>
#include <string.h>
#include <stdio.h>
#include "messages.h"
#pragma warn -par

#define SWITCH_DELAY 250	// hardcoded delay for desktop switching
#define MsgError(s) \
    MessageBox(0,(s),"Error",MB_ICONERROR|MB_OK)

int WINAPI WinMain(
    HINSTANCE hInst,
    HINSTANCE hPrevInst,
    LPSTR lpCmdLine,
    int nShowCmd)
{
    // Check command line parameter count
    if (_argc < 2)
    {
        MsgError(
            "Cmd-line parameters missing.\n"
            "See \"vwrun.cpp\" for more information."
        );
        return 0;
    }
    // Check wheter VirtuaWin is loaded or not
    HWND hWnd = FindWindow("VirtuaWinMainClass","VirtuaWinMainClass");
    if (!hWnd)
    {
        MsgError("VirtuaWin not loaded.");
        return 0;
    }
    // Get current desktop number
    int curnum = SendMessage(hWnd,VW_CURDESK,0,0);
    if ((curnum < 1) || (curnum > 9))
        return 0; //mmh, should never happen ;-)

    // Get desktop number specified at command line
    int num = atoi(_argv[1]);
    if ((num < 1) || (num > 9))
    {
        char temp[80];
        sprintf(temp,
            "Invalid desktop number %d.\n"
            "(use range 1..9)",num);
        MsgError(temp);
        return 0;
    }
    // Set given desktop
    if (num != curnum)
        SendMessage(hWnd,VW_CHANGEDESK,num,0);

    // Execute application on desktop?
    if (_argc > 2)
    {
        // Jump back to old desktop number?
        bool bSwitch = 1;
        if (_argv[3]) if (!stricmp(_argv[3],"/stay")) { bSwitch = 0; _argv[3]=NULL; }
        if (_argv[4]) if (!stricmp(_argv[4],"/stay")) { bSwitch = 0; _argv[4]=NULL; }

        // Prepare stuff for application execution
        PROCESS_INFORMATION ProcessInfo;
        STARTUPINFO StartupInfo;
        ZeroMemory(&StartupInfo,sizeof(STARTUPINFO));
        StartupInfo.cb = sizeof(STARTUPINFO);

        // Build up command-line string
        char temp[512];
        sprintf(temp,"%s %s",
            _argv[2]?_argv[2]:"",
            _argv[3]?_argv[3]:"");

        // Create application process
        bool state = 
        CreateProcess(
            NULL,temp,NULL,NULL,TRUE,
            NORMAL_PRIORITY_CLASS,NULL,NULL,
            &StartupInfo,&ProcessInfo
        );
        // If we succeeded
        if (state)
        {
            // Wait for app to initialize
            WaitForInputIdle(ProcessInfo.hProcess,10000);

            // Clean up process stuff
            CloseHandle(ProcessInfo.hProcess);
            CloseHandle(ProcessInfo.hThread);
        }
        // Make system a bit happier ...
        Sleep(SWITCH_DELAY);

        // Jump back to old desktop number?
        if (bSwitch)
            SendMessage(hWnd,VW_CHANGEDESK,curnum,0);
    }
    // Return with success
    return 1;
}
/* EOF */
